@@ -37,9 +37,6 @@
 //! let token = sm.lookup_token(0, 0).unwrap(); // line-number and column
 //! println!("token: {}", token);
 //! ```
-#![cfg_attr(feature="serde_derive", feature(proc_macro))]
-
-#[cfg(feature = "serde_derive")]
 #[macro_use]
 extern crate serde_derive;
 
